@@ -36,25 +36,26 @@
 
 #include "config.h"
 
-#include <cstring>
 #include <algorithm>
-#include <functional>
-#include <csignal>
 #include <csetjmp>
+#include <csignal>
+#include <cstring>
+#include <functional>
 
 #include "torrent/exceptions.h"
 
 #include "chunk.h"
 #include "chunk_iterator.h"
 
+namespace {
 jmp_buf jmp_disk_full;
 
 void
-bus_handler(int sig, siginfo_t *si, void *vuctx)
-{
-    if (si->si_code == BUS_ADRERR)
-        longjmp(jmp_disk_full, 1);
+bus_handler(int, siginfo_t* si, void*) {
+  if (si && si->si_code == BUS_ADRERR)
+    longjmp(jmp_disk_full, 1);
 }
+} // namespace
 
 namespace torrent {
 
@@ -235,9 +236,8 @@ Chunk::to_buffer(void* buffer, uint32_t position, uint32_t length) {
 // matching.
 bool
 Chunk::from_buffer(const void* buffer, uint32_t position, uint32_t length) {
-  struct sigaction sa, oldact;
-  std::memset(&sa, 0, sizeof(sa));
-  sa.sa_sigaction = bus_handler;
+  struct sigaction sa{}, oldact;
+  sa.sa_sigaction = &bus_handler;
   sa.sa_flags = SA_SIGINFO;
   sigfillset(&sa.sa_mask);
   sigaction(SIGBUS, &sa, &oldact);
@@ -292,4 +292,4 @@ Chunk::compare_buffer(const void* buffer, uint32_t position, uint32_t length) {
   return true;
 }
 
-}
+} // namespace torrent
