@@ -3,17 +3,13 @@
 #include "data/hash_queue.h"
 
 #include <functional>
-#include <unistd.h>
 #include <utility>
 
-#include "data/chunk.h"
-#include "data/chunk_list_node.h"
 #include "data/hash_chunk.h"
 #include "data/thread_disk.h"
-#include "torrent/exceptions.h"
 #include "torrent/data/download_data.h"
+#include "torrent/exceptions.h"
 #include "torrent/utils/log.h"
-#include "torrent/utils/thread.h"
 
 #define LT_LOG_DATA(data, log_level, log_fmt, ...)                       \
   lt_log_print_data(LOG_STORAGE_##log_level, data, "hash_queue", log_fmt, __VA_ARGS__);
@@ -147,4 +143,4 @@ HashQueue::chunk_done(HashChunk* hash_chunk, const HashString& hash_value) {
   m_cv.notify_all();
 }
 
-}
+} // namespace torrent
