@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,7 +38,6 @@
 
 #include "hash_chunk.h"
 #include "hash_queue_node.h"
-#include "chunk_list_node.h"
 
 namespace torrent {
 
@@ -63,4 +62,4 @@ HashQueueNode::call_willneed() {
   return m_chunk->remaining();
 }
 
-}
+} // namespace torrent
