@@ -1,10 +1,9 @@
-#ifndef LIBTORRENT_DHT_ROUTER_H
-#define LIBTORRENT_DHT_ROUTER_H
+#ifndef LIBTORRENT_DHT_DHT_ROUTER_H
+#define LIBTORRENT_DHT_DHT_ROUTER_H
 
 #include "dht/dht_node.h"
 #include "dht/dht_hash_map.h"
 #include "dht/dht_server.h"
-#include "rak/socket_address.h"
 #include "torrent/hash_string.h"
 #include "torrent/object.h"
 #include "torrent/net/types.h"
@@ -36,7 +35,7 @@ public:
   // A node ID of all zero.
   static HashString zero_id;
 
-  DhtRouter(const Object& cache, const rak::socket_address* sa);
+  DhtRouter(const Object& cache);
   ~DhtRouter();
 
   void                start(int port);
@@ -57,6 +56,9 @@ public:
 
   // Add the given host to the list of potential contacts if we haven't
   // completed the bootstrap process, or contact the given address directly.
+
+  // TODO: Remoce add_contact.... And make it check that sa is inet.
+
   void                add_contact(const std::string& host, int port);
   void                contact(const sockaddr* sa, int port);
 
@@ -65,13 +67,13 @@ public:
   DhtNode*            get_node(const HashString& id);
 
   // Search for node with given address in O(n), disregarding the port.
-  DhtNode*            find_node(const rak::socket_address* sa);
+  DhtNode*            find_node(const sockaddr* sa);
 
   // Whenever a node queries us, replies, or is confirmed inactive (no reply) or
   // invalid (reply with wrong ID), we need to update its status.
-  DhtNode*            node_queried(const HashString& id, const rak::socket_address* sa);
-  DhtNode*            node_replied(const HashString& id, const rak::socket_address* sa);
-  DhtNode*            node_inactive(const HashString& id, const rak::socket_address* sa);
+  DhtNode*            node_queried(const HashString& id, const sockaddr* sa);
+  DhtNode*            node_replied(const HashString& id, const sockaddr* sa);
+  DhtNode*            node_inactive(const HashString& id, const sockaddr* sa);
   void                node_invalid(const HashString& id);
 
   // Store compact node information (26 bytes) for nodes closest to the
@@ -82,15 +84,12 @@ public:
   Object*             store_cache(Object* container) const;
 
   // Create and verify a token. Tokens are valid between 15-30 minutes from creation.
-  raw_string          make_token(const rak::socket_address* sa, char* buffer);
-  bool                token_valid(raw_string token, const rak::socket_address* sa);
+  raw_string          make_token(const sockaddr* sa, char* buffer) const;
+  bool                token_valid(raw_string token, const sockaddr* sa) const;
 
   tracker::DhtController::statistics_type get_statistics() const;
   void                                    reset_statistics()  { m_server.reset_statistics(); }
 
-  void                set_upload_throttle(ThrottleList* t)    { m_server.set_upload_throttle(t); }
-  void                set_download_throttle(ThrottleList* t)  { m_server.set_download_throttle(t); }
-
 private:
   // Hostname and port of potential bootstrap nodes.
   using contact_t = std::pair<std::string, int>;
@@ -119,7 +118,7 @@ private:
   void                receive_timeout_bootstrap();
 
   // buffer needs to hold an SHA1 hash (20 bytes), not just the token (8 bytes)
-  char*               generate_token(const rak::socket_address* sa, int token, char buffer[20]);
+  static char*        generate_token(const sockaddr* sa, int token, char buffer[20]);
 
   utils::SchedulerEntry m_task_timeout;
 
@@ -140,10 +139,10 @@ private:
 };
 
 inline raw_string
-DhtRouter::make_token(const rak::socket_address* sa, char* buffer) {
+DhtRouter::make_token(const sockaddr* sa, char* buffer) const {
   return raw_string(generate_token(sa, m_curToken, buffer), size_token);
 }
 
-}
+} // namespace torrent
 
 #endif
