@@ -5,30 +5,28 @@
 #include <algorithm>
 #include <cstdio>
 #include <cstring>
-#include <string.h>
-#include <rak/string_manip.h>
 
 #include "download/download_wrapper.h"
-#include "torrent/exceptions.h"
+#include "rak/string_manip.h"
 #include "torrent/data/file.h"
 #include "torrent/data/file_list.h"
-#include "torrent/tracker/dht_controller.h"
-#include "tracker/tracker_controller.h"
+#include "torrent/download_info.h"
+#include "torrent/exceptions.h"
 #include "tracker/tracker_list.h"
 
 #include "manager.h"
 
 namespace torrent {
 
-bool
+static bool
 download_constructor_is_single_path(Object::map_type::const_reference v) {
   return v.first.rfind("name.", 0) == 0 && v.second.is_string();
-};
+}
 
-bool
+static bool
 download_constructor_is_multi_path(Object::map_type::const_reference v) {
   return v.first.rfind("path.", 0) == 0 && v.second.is_list();
-};
+}
 
 void
 DownloadConstructor::initialize(Object& b) {
@@ -142,24 +140,22 @@ DownloadConstructor::parse_tracker(const Object& b) {
       // entries while still having valid 'announce'.
       !(announce_list = &b.get_key_list("announce-list"))->empty() &&
       std::any_of(announce_list->begin(), announce_list->end(), std::mem_fn(&Object::is_list))) {
+
     for (const auto& group : *announce_list) {
       add_tracker_group(group);
     }
   } else if (b.has_key("announce")) {
     add_tracker_single(b.get_key("announce"), 0);
-
-  } else if (!manager->dht_controller()->is_valid() || m_download->info()->is_private()) {
-    throw bencode_error("Could not find any trackers");
   }
 
-  if (manager->dht_controller()->is_valid() && !m_download->info()->is_private())
+  if (!m_download->info()->is_private())
     m_download->main()->tracker_list()->insert_url(m_download->main()->tracker_list()->size_group(), "dht://");
 
-  if (manager->dht_controller()->is_valid() && b.has_key_list("nodes")) {
-    for (const auto& node : b.get_key_list("nodes")) {
-      add_dht_node(node);
-    }
-  }
+  // Deprecating DHT nodes key in torrent files as this is no longer needed.
+  // if (b.has_key_list("nodes")) {
+  //   for (const auto& node : b.get_key_list("nodes"))
+  //     add_dht_node(node);
+  // }
 
   m_download->main()->tracker_list()->randomize_group_entries();
 }
@@ -184,24 +180,6 @@ DownloadConstructor::add_tracker_single(const Object& b, int group) {
   m_download->main()->tracker_list()->insert_url(group, rak::trim_classic(b.as_string()));
 }
 
-void
-DownloadConstructor::add_dht_node(const Object& b) {
-  if (!b.is_list() || b.as_list().size() < 2)
-    return;
-
-  auto el = b.as_list().begin();
-
-  if (!el->is_string())
-    return;
-
-  const std::string& host = el->as_string();
-
-  if (!(++el)->is_value())
-    return;
-
-  manager->dht_controller()->add_node(host, el->as_value());
-}
-
 bool
 DownloadConstructor::is_valid_path_element(const Object& b) {
   return
@@ -418,12 +396,12 @@ DownloadConstructor::parse_magnet_uri(Object& b, const std::string& uri) {
 
     if (raw_bencode_equal_c_str(tag, "xt")) {
       // url-encoded hash as per magnet URN specs
-      if (decoded.length() == hash.size_data) {
+      if (decoded.length() == torrent::HashString::size_data) {
         hash = *HashString::cast_from(decoded);
         hashValid = true;
 
       // hex-encoded hash as per BEP 0009
-      } else if (decoded.length() == hash.size_data * 2) {
+      } else if (decoded.length() == torrent::HashString::size_data * 2) {
         std::string::iterator hexItr = decoded.begin();
         for (HashString::iterator itr = hash.begin(), last = hash.end(); itr != last; itr++, hexItr += 2)
           *itr = (rak::hexchar_to_value(*hexItr) << 4) + rak::hexchar_to_value(*(hexItr + 1));
@@ -453,4 +431,4 @@ DownloadConstructor::parse_magnet_uri(Object& b, const std::string& uri) {
   }
 }
 
-}
+} // namespace torrent
