@@ -17,11 +17,13 @@ public:
   ~ThreadNet() override;
 
   static void         create_thread();
+  static void         destroy_thread();
   static ThreadNet*   thread_net();
 
   const char*         name() const override { return "rtorrent net"; }
 
   void                init_thread() override;
+  void                init_thread_post_local() override;
   void                cleanup_thread() override;
 
 protected:
