@@ -8,7 +8,6 @@
 #include "torrent/object.h"
 #include "torrent/object_static_map.h"
 
-#include "torrent/download_info.h"
 #include "net/address_list.h"
 #include "net/data_buffer.h"
 
@@ -196,6 +195,6 @@ ProtocolExtension::id(int t) const {
   return m_idMap[t - 1];
 }
 
-}
+} // namespace torrent
 
 #endif
