@@ -4,8 +4,6 @@
 
 #include <algorithm>
 #include <cassert>
-#include <cinttypes>
-#include <functional>
 
 #include "download/delegator.h"
 #include "protocol/peer_chunks.h"
@@ -60,7 +58,7 @@ request_list_constants::destroy<BlockTransfer*>(BlockTransfer*& obj) {
 struct request_list_same_piece {
   request_list_same_piece(const Piece& p) : m_piece(p) {}
 
-  bool operator () (const BlockTransfer* d) {
+  bool operator () (const BlockTransfer* d) const {
     return
       m_piece.index() == d->piece().index() &&
       m_piece.offset() == d->piece().offset();
@@ -243,7 +241,7 @@ RequestList::downloading(const Piece& piece) {
 
   default:
     goto downloading_error;
-  };
+  }
 
   // We received an invalid piece length, propably zero length due to
   // the peer not being able to transfer the requested piece.
@@ -347,4 +345,4 @@ RequestList::calculate_pipe_size(uint32_t rate) {
   }
 }
 
-}
+} // namespace torrent
