@@ -1,43 +1,7 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DATA_DOWNLOAD_DATA_H
 #define LIBTORRENT_DATA_DOWNLOAD_DATA_H
 
-#include lt_tr1_functional
+#include <functional>
 
 #include <torrent/common.h>
 #include <torrent/bitfield.h>
@@ -53,15 +17,11 @@ class FileList;
 
 class download_data {
 public:
-  typedef ranges<uint32_t> priority_ranges;
+  using priority_ranges = ranges<uint32_t>;
 
-  typedef void (function_void)(void);
+  using slot_void = std::function<void()>;
 
-  typedef std::function<function_void> slot_void;
-
-  typedef void (function_chunk_list_node_p)(ChunkListNode *); 
-  typedef std::function<function_chunk_list_node_p> slot_chunk_list_node_p;
-  download_data() : m_wanted_chunks(0) {}
+  using slot_chunk_list_node_p = std::function<void(ChunkListNode*)>;
 
   const HashString&      hash() const                  { return m_hash; }
 
@@ -116,7 +76,7 @@ private:
   priority_ranges        m_high_priority;
   priority_ranges        m_normal_priority;
 
-  uint32_t               m_wanted_chunks;
+  uint32_t               m_wanted_chunks{0};
 
   mutable slot_void      m_slot_initial_hash;
   mutable slot_void      m_slot_download_done;
@@ -125,6 +85,6 @@ private:
   mutable slot_chunk_list_node_p m_slot_chunk_done;
 };
 
-}
+} // namespace torrent
 
 #endif // LIBTORRENT_DATA_DOWNLOAD_DATA_H
