@@ -5,13 +5,12 @@
 #include <algorithm>
 #include <cstdint>
 #include <cstring>
-#include <functional>
 #include <limits>
 #include <memory>
-#include <set>
 #include <rak/error_number.h>
 #include <rak/file_stat.h>
 #include <rak/fs_stat.h>
+#include <set>
 
 #include "manager.h"
 #include "piece.h"
@@ -29,7 +28,7 @@
 
 namespace torrent {
 
-void
+static void
 verify_file_list(const FileList* fl) {
   if (fl->empty())
     throw internal_error("verify_file_list() 1.", fl->data()->hash());
@@ -43,6 +42,8 @@ verify_file_list(const FileList* fl) {
       throw internal_error("verify_file_list() 3.", fl->data()->hash());
 }
 
+FileList::FileList() = default;
+
 FileList::~FileList() {
   // Can we skip close()?
   close();
@@ -416,7 +417,7 @@ FileList::open(bool hashing, int flags) {
       lastPath = *entry->path();
     }
 
-  } catch (local_error& e) {
+  } catch (const local_error& e) {
     for (auto& entry : *this) {
       entry->unset_flags_protected(File::flag_active);
       manager->file_manager()->close(entry.get());
@@ -546,12 +547,12 @@ FileList::open_file(File* file_node, const Path& lastPath, bool hashing, int fla
 }
 
 MemoryChunk
-FileList::create_chunk_part(FileList::iterator itr, uint64_t offset, uint32_t length, bool hashing, int prot) {
+FileList::create_chunk_part(FileList::iterator itr, uint64_t offset, uint32_t length, bool hashing, int prot) const {
   offset -= (*itr)->offset();
   length = std::min<uint64_t>(length, (*itr)->size_bytes() - offset);
 
   if ((*itr)->is_padding())
-    return SocketFile().create_padding_chunk(length, prot, MemoryChunk::map_shared);
+    return SocketFile::create_padding_chunk(length, prot, MemoryChunk::map_shared);
 
   if (static_cast<int64_t>(offset) < 0)
     throw internal_error("FileList::chunk_part(...) caught a negative offset", data()->hash());
@@ -674,7 +675,7 @@ FileList::inc_completed(iterator firstItr, uint32_t index) {
   // TODO: Check if this works right for zero-length files.
   std::for_each(firstItr,
                 lastItr == end() ? end() : (lastItr + 1),
-                [](value_type& file) { file->inc_completed_protected(); });
+                std::mem_fn(&File::inc_completed_protected));
 
   return lastItr;
 }
@@ -724,4 +725,4 @@ FileList::reset_filesize(int64_t size) {
   open(false, open_no_create);
 }
 
-}
+} // namespace torrent
