@@ -1,23 +1,22 @@
 #include "config.h"
 
 #include <cinttypes>
+#include <numeric>
 
-#include "data/block.h"
 #include "data/block_list.h"
 #include "data/chunk_list.h"
 #include "data/hash_queue.h"
 #include "data/hash_torrent.h"
-#include "download/available_list.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
 #include "download/download_wrapper.h"
 #include "protocol/peer_connection_base.h"
 #include "protocol/peer_factory.h"
-#include "peer/peer_info.h"
+#include "torrent/data/file.h"
 #include "torrent/download/choke_group.h"
 #include "torrent/download/choke_queue.h"
 #include "torrent/download_info.h"
-#include "torrent/data/file.h"
+#include "torrent/net/socket_address.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/utils/log.h"
 
@@ -31,19 +30,6 @@
 
 namespace torrent {
 
-const int DownloadInfo::flag_open;
-const int DownloadInfo::flag_active;
-const int DownloadInfo::flag_accepting_new_peers;
-const int DownloadInfo::flag_accepting_seeders;
-const int DownloadInfo::flag_private;
-const int DownloadInfo::flag_meta_download;
-const int DownloadInfo::flag_pex_enabled;
-const int DownloadInfo::flag_pex_active;
-
-const int DownloadInfo::public_flags;
-
-const uint32_t DownloadInfo::unlimited;
-
 const DownloadInfo* Download::info() const { return m_ptr->info(); }
 const download_data* Download::data() const { return m_ptr->data(); }
 
@@ -119,7 +105,7 @@ Download::start(int flags) {
     info->set_uploaded_baseline(info->up_rate()->total());
     info->set_completed_baseline(m_ptr->main()->file_list()->completed_bytes());
 
-    lt_log_print_info(LOG_TRACKER_INFO, info,
+    lt_log_print_info(LOG_TRACKER_EVENTS, info,
                       "download", "Setting new baseline on start: uploaded:%" PRIu64 " completed:%" PRIu64 ".",
                       info->uploaded_baseline(), info->completed_baseline());
   }
@@ -143,8 +129,16 @@ Download::stop(int flags) {
   m_ptr->main()->tracker_controller().disable();
 }
 
+// When session data is loaded, it includes a bitfield and list of files+mtime.
+//
+// As the download is opened it checks the mtimes of the files, if the file is missing or has wrong mtime then
+// the file's range is added to hashing_ranges() and the bitfield range is cleared.
+//
+// Hash check with try_quick never does any actual hashing, it only checks if the underlying file
+// exists and if it does it fails the whole try_quick hash check.
+
 bool
-Download::hash_check(bool tryQuick) {
+Download::hash_check(bool try_quick) {
   if (m_ptr->hash_checker()->is_checking())
     throw internal_error("Download::hash_check(...) called but the hash is already being checked.");
 
@@ -156,7 +150,7 @@ Download::hash_check(bool tryQuick) {
 
   Bitfield* bitfield = m_ptr->data()->mutable_completed_bitfield();
 
-  LT_LOG_THIS(INFO, "Checking hash: allocated:%i try_quick:%i.", !bitfield->empty(), (int)tryQuick);
+  LT_LOG_THIS(INFO, "Checking hash: allocated:%i try_quick:%i.", !bitfield->empty(), (int)try_quick);
 
   if (bitfield->empty()) {
     // The bitfield still hasn't been allocated, so no resume data was
@@ -165,11 +159,19 @@ Download::hash_check(bool tryQuick) {
     bitfield->unset_all();
 
     m_ptr->hash_checker()->hashing_ranges().insert(0, m_ptr->main()->file_list()->size_chunks());
+
+  } else if (!try_quick) {
+    // Clear ranges we're about to recheck so mark_completed can re-set them.
+    for (auto range : m_ptr->hash_checker()->hashing_ranges())
+      bitfield->unset_range(range.first, range.second);
+
+    // TODO: Consider adding a sanity check above instead, and print out the files (size+range) of
+    // the invalid marked bit.
   }
 
   m_ptr->main()->file_list()->update_completed();
 
-  return m_ptr->hash_checker()->start(tryQuick);
+  return m_ptr->hash_checker()->start(try_quick);
 }
 
 // Propably not correct, need to clear content, etc.
@@ -256,16 +258,13 @@ Download::connection_list() const {
 
 uint64_t
 Download::bytes_done() const {
-  uint64_t a = 0;
+  uint64_t a = m_ptr->main()->file_list()->completed_bytes();
 
-  Delegator* d = m_ptr->main()->delegator();
-
-  for (auto itr1 : *d->transfer_list())
-    for (const auto& itr2 : *itr1)
-      if (itr2.is_finished())
-        a += itr2.piece().length();
-
-  return a + m_ptr->main()->file_list()->completed_bytes();
+  for (auto list : *m_ptr->main()->delegator()->transfer_list())
+    a += std::accumulate(list->begin(), list->end(), uint64_t{}, [](auto sum, const auto& t) {
+      return t.is_finished() ? sum + t.piece().length() : sum;
+    });
+  return a;
 }
 
 uint32_t
@@ -309,7 +308,7 @@ Download::set_bitfield(bool allSet) {
 }
 
 void
-Download::set_bitfield(uint8_t* first, uint8_t* last) {
+Download::set_bitfield(const uint8_t* first, const uint8_t* last) {
   if (m_ptr->hash_checker()->is_checked() || m_ptr->hash_checker()->is_checking())
     throw input_error("Download::set_bitfield(...) Download in invalid state.");
 
@@ -515,7 +514,7 @@ Download::set_connection_type(ConnectionType t) {
     break;
   default:
     throw input_error("torrent::Download::set_connection_type(...) received an unknown type.");
-  };
+  }
 
   m_ptr->set_connection_type(t);
 }
@@ -556,11 +555,12 @@ Download::add_peer(const sockaddr* sa, int port) {
   if (m_ptr->info()->is_private())
     return;
 
-  rak::socket_address sa_port = *rak::socket_address::cast_from(sa);
-  sa_port.set_port(port);
-  m_ptr->main()->add_peer(sa_port);
+  auto tmp = sa_copy(sa);
+  sap_set_port(tmp, port);
+
+  m_ptr->main()->add_peer(tmp.get());
 }
 
 DownloadMain* Download::main() { return m_ptr->main(); }
 
-}
+} // namespace torrent
