@@ -1,12 +1,11 @@
 #include "config.h"
 
-#include <iterator>
 #include <iostream>
-#include <cmath>
+#include <iterator>
 #include <limits>
 #include <stdexcept>
+
 #include <rak/algorithm.h>
-#include <rak/string_manip.h>
 
 #include "utils/sha1.h"
 
@@ -16,7 +15,7 @@
 
 namespace torrent {
 
-bool
+static bool
 object_read_string(std::istream* input, std::string& str) {
   uint32_t size;
   *input >> size;
@@ -27,7 +26,7 @@ object_read_string(std::istream* input, std::string& str) {
   try {
   	str.resize(size);
 
-  } catch (std::length_error& e) {
+  } catch (const std::length_error&) {
     return false;
   }
 
@@ -40,7 +39,7 @@ object_read_string(std::istream* input, std::string& str) {
   return !input->fail();
 }
 
-const char*
+static const char*
 object_read_bencode_c_value(const char* first, const char* last, int64_t& value) {
   if (first == last)
     return first;
@@ -72,7 +71,7 @@ object_read_bencode_c_string(const char* first, const char* last) {
   // Set the most-significant bit so that if there are no numbers in
   // the input it will fail the length check, while "0" will shift the
   // bit out.
-  unsigned int length = 0x1 << (std::numeric_limits<unsigned int>::digits - 1);
+  unsigned int length = 0x1U << (std::numeric_limits<unsigned int>::digits - 1);
 
   while (first != last && *first >= '0' && *first <= '9')
     length = length * 10 + (*first++ - '0');
@@ -114,13 +113,13 @@ object_read_bencode(std::istream* input, Object* object, uint32_t depth) {
 	return;
       }
 
-      auto itr = object->as_list().insert(object->as_list().end(), Object());
-      object_read_bencode(input, &*itr, depth);
+      auto& obj = object->as_list().emplace_back();
+      object_read_bencode(input, &obj, depth);
 
       // The unordered flag is inherited also from list elements who
       // have been marked as unordered, though e.g. unordered strings
       // in the list itself does not cause this flag to be set.
-      if (itr->flags() & Object::flag_unordered)
+      if (obj.flags() & Object::flag_unordered)
         object->set_internal_flags(Object::flag_unordered);
     }
 
@@ -205,13 +204,13 @@ object_read_bencode_c(const char* first, const char* last, Object* object, uint3
       if (*first == 'e')
 	return first + 1;
 
-      auto itr = object->as_list().insert(object->as_list().end(), Object());
-      first = object_read_bencode_c(first, last, &*itr, depth);
+      auto& obj = object->as_list().emplace_back();
+      first = object_read_bencode_c(first, last, &obj, depth);
 
       // The unordered flag is inherited also from list elements who
       // have been marked as unordered, though e.g. unordered strings
       // in the list itself does not cause this flag to be set.
-      if (itr->flags() & Object::flag_unordered)
+      if (obj.flags() & Object::flag_unordered)
         object->set_internal_flags(Object::flag_unordered);
     }
 
@@ -267,7 +266,7 @@ object_read_bencode_c(const char* first, const char* last, Object* object, uint3
   throw torrent::bencode_error("Invalid bencode data.");
 }
 
-inline bool object_is_not_digit(char c) { return c < '0' || c > '9'; }
+static bool object_is_not_digit(char c) { return c < '0' || c > '9'; }
 
 const char*
 object_read_bencode_skip_c(const char* first, const char* last) {
@@ -316,7 +315,7 @@ object_read_bencode_skip_c(const char* first, const char* last) {
 
     default:
       first = object_read_bencode_c_string(first, last).end();
-    };
+    }
 
     if (stack_itr == stack)
       return first;
@@ -325,7 +324,7 @@ object_read_bencode_skip_c(const char* first, const char* last) {
   throw torrent::bencode_error("Invalid bencode data.");
 }
 
-const char*
+static const char*
 object_read_bencode_raw_c(const char* first, const char* last, torrent::Object* object, char type) {
   const char* tmp = first;
   first = object_read_bencode_skip_c(first, last);
@@ -350,7 +349,7 @@ object_read_bencode_raw_c(const char* first, const char* last, torrent::Object*
     break;
   default:
     *object = obj;
-  };
+  }
 
   return first;
 }
@@ -393,7 +392,7 @@ struct object_write_data_t {
   char* pos;
 };
 
-void
+static void
 object_write_bencode_c_string(object_write_data_t* output, const char* srcData, uint32_t srcLength) {
   while (srcLength != 0) {
     uint32_t len = std::min<uint32_t>(srcLength, std::distance(output->pos, output->buffer.second));
@@ -414,7 +413,7 @@ object_write_bencode_c_string(object_write_data_t* output, const char* srcData,
   }
 }
 
-void
+static void
 object_write_bencode_c_char(object_write_data_t* output, char src) {
   if (output->pos == output->buffer.second) {
     output->buffer = output->writeFunc(output->data, output->buffer);
@@ -428,7 +427,7 @@ object_write_bencode_c_char(object_write_data_t* output, char src) {
 }
 
 // A new wheel. Look, how shiny and new.
-void
+static void
 object_write_bencode_c_value(object_write_data_t* output, int64_t src) {
   if (src == 0)
     return object_write_bencode_c_char(output, '0');
@@ -451,26 +450,26 @@ object_write_bencode_c_value(object_write_data_t* output, int64_t src) {
   object_write_bencode_c_string(output, first, 20 - std::distance(buffer, first));
 }
 
-inline void
+static void
 object_write_bencode_c_obj_value(object_write_data_t* output, int64_t value) {
   object_write_bencode_c_char(output, 'i');
   object_write_bencode_c_value(output, value);
   object_write_bencode_c_char(output, 'e');
 }
 
-inline void
+static void
 object_write_bencode_c_obj_string(object_write_data_t* output, const char* data, uint32_t size) {
   object_write_bencode_c_value(output, size);
   object_write_bencode_c_char(output, ':');
   object_write_bencode_c_string(output, data, size);
 }
 
-inline void
+static void
 object_write_bencode_c_obj_string(object_write_data_t* output, const std::string& str) {
   object_write_bencode_c_obj_string(output, str.c_str(), str.size());
 }
 
-void
+static void
 object_write_bencode_c_object(object_write_data_t* output, const Object* object, uint32_t skip_mask) {
   switch (object->type()) {
   case Object::TYPE_NONE: break;
@@ -535,7 +534,6 @@ object_write_bencode_c_object(object_write_data_t* output, const Object* object,
     break;
   case Object::TYPE_DICT_KEY:
     throw torrent::bencode_error("Cannot bencode internal dict_key type.");
-    break;
   }
 }
 
@@ -757,13 +755,13 @@ static_map_read_bencode_c(const char* first,
     }
     default:
       throw internal_error("static_map_read_bencode_c: key_search.first->key[base] returned invalid character.");
-    };
+    }
   }
   
   throw torrent::bencode_error("Invalid bencode data.");
 }
 
-void
+static void
 static_map_write_bencode_c_values(object_write_data_t* output,
                                  const static_map_entry_type* entry_values,
                                  const static_map_mapping_type* first_key,
@@ -874,4 +872,4 @@ static_map_write_bencode_c_wrap(object_write_t writeFunc,
   return output.writeFunc(output.data, object_buffer_t(output.buffer.first, output.pos));
 }
 
-}
+} // namespace torrent
