@@ -38,12 +38,9 @@ public:
   void                send_scrape() override;
 
   void                close() override;
-  void                disown() override;
 
   tracker_enum        type() const override;
 
-  void                get_status(char* buffer, int length);
-
   state_type          get_dht_state() const            { return m_dht_state; }
   void                set_dht_state(state_type state)  { m_dht_state = state; }
 
@@ -55,13 +52,13 @@ public:
   void                receive_progress(int replied, int contacted);
 
 private:
-  AddressList  m_peers;
-  state_type   m_dht_state{state_idle};
+  AddressList         m_peers;
+  state_type          m_dht_state{state_idle};
 
-  int          m_replied;
-  int          m_contacted;
+  int                 m_replied;
+  int                 m_contacted;
 };
 
-}
+} // namespace torrent
 
 #endif
