@@ -18,7 +18,7 @@ public:
   static void                      cancel_callback(void* target)                       { Thread::m_self->cancel_callback(target); }
   static void                      cancel_callback_and_wait(void* target)              { Thread::m_self->cancel_callback_and_wait(target); }
 
-  static Poll*                     poll()           { return Thread::m_self->m_poll.get(); }
+  static net::Poll*                poll()           { return Thread::m_self->m_poll.get(); }
   static Scheduler*                scheduler()      { return Thread::m_self->m_scheduler.get(); }
   static net::Resolver*            resolver()       { return Thread::m_self->m_resolver.get(); }
 };
