@@ -12,8 +12,5 @@ class AllocatorsTest : public CppUnit::TestFixture {
 public:
   typedef std::vector<char, rak::cacheline_allocator<char> > aligned_vector_type;
 
-  void setUp() {}
-  void tearDown() {}
-
   void testAlignment();
 };
